/**
 * Method: Define W = (N + 1) / 2 and L = K - W as the winner's and loser's
 * points, respectively. Now define S(i, j) as the expected number of
 * interesting games if the score is i-j. The answer to the problem will be
 * in S(0, 0). Then S(i, j) = 
 *
 * 0    if i + j = K
 *     (explanation: the match is over)
 * S(i, j + 1)    if i = W - 1 and j < L
 *     (explanation: P2 must win the next one or the match ends prematurely)
 * S(i + 1, j)    if j = W - 1 and i < L
 *     (by symmetry)
 * S(i, j + 1)    if i = L and j > L
 *     (explanation: P2 wins all the remaining games)
 * S(i + 1, j)    if j = L and i > L
 *     (by symmetry)
 * 1 + (S(i + 1, j) + S(i, j + 1)) / 2    otherwise
 *     (explanation: the next game is interesting)
 *
 * Since the matrix is symmetrical, we only need a W x L matrix. We then
 * have to rewrite the formula along the diagonal (when i = j):
 *
 * S(i, j) = 1 + S(i + 1, j)
 *
 * Since all the divisions are by 2, it follows that S(i, j) are fractions
 * where the denominator is a power of 2. We could compute S bottom-to-top
 * and right-to-left, but that would require adding arbitrary fractions.
 * Note, however, that elements along an antidiagonal (i + j = constant)
 * have the same denominator. Therefore, we compute S in antidiagonal order
 * and we do not store the denominators explicitly. For example, in the
 * general case:
 *
 * S(i, j) = 1 + (x/2^k + y/2^k) / 2 = (2^(k + 1) + x + y) / 2^(k+1)
 *
 * So we can compute the numerator in place:
 *
 * p[j] = 2^(k + 1) + p[j] + p[j + 1]
 *
 * We only use O(N) memory for the current antidiagonal. We reduce the
 * fraction once, at the end.
 **/
#include <stdio.h>

#define MAX_W 1000
#define MAX_DIGITS 70 /* 2000 * 2^2000, 9 decimal digits per place */
#define BASE 1000000000
#define MIN(X, Y) (((X) < (Y)) ? (X) : (Y))

typedef struct {
  int n;
  int d[MAX_DIGITS];
} huge;

huge p[MAX_W];

/* h = d, where d is a single digit */
void assign(huge *h, int d) {
  h->n = 1;
  h->d[0] = d;
}

int even(huge *h) {
  return !(h->d[0] & 1);
}

/* h *= 2 */
void twice(huge *h) {
  int c = 0, i;

  for (i = 0; i < h->n; i++) {
    h->d[i] = (h->d[i] << 1) + c;
    c = (h->d[i] >= BASE);
    h->d[i] -= BASE * c;
  }
  if (c) {
    h->d[h->n++] = 1;
  }
}

/* h /= 2 */
void half(huge *h) {
  int c = 0, i;

  for (i = h->n - 1; i >= 0; i--) {
    h->d[i] += BASE * c;
    c = h->d[i] & 1;
    h->d[i] >>= 1;
  }
  if (h->n && !h->d[h->n - 1]) {
    h->n--;
  }
}

/* a += b */
void sum(huge *a, huge *b) {
  while (a->n < b->n) {
    a->d[a->n++] = 0;
  }
  while (b->n < a->n) {
    b->d[b->n++] = 0;
  }

  int c = 0, i;
  for (i = 0; i < a->n; i++) {
    a->d[i] += b->d[i] + c;
    c = (a->d[i] >= BASE);
    a->d[i] -= BASE * c;
  }
  if (c) {
    a->d[a->n++] = 1;
  }
}

void print(huge *h, FILE *f) {
  int i;

  fprintf(f, "%d", h->d[h->n - 1]);
  for (i = h->n - 2; i >= 0; i--) {
    fprintf(f, "%09d", h->d[i]);
  }
  fprintf(f, "\n");
}

int main() {
  int n, k, w, l, i, s;

  FILE *f = fopen("spoiler.in", "r");
  fscanf(f, "%d%d", &n, &k);
  fclose(f);

  w = (n + 1) / 2; /* winner's points */
  l = k - w;       /* loser's points */

  huge q;
  assign(&q, 2);
  for (s = k - 1; s >= 0; s--) {
    for (i = MIN(s, w - 1); i >= s - i; i--) {
      int j = s - i;
      if (i == j) {
        /* S(i, j) = 1 + S(i + 1, j) */
        twice(&p[j]);
        sum(&p[j], &q);
      } else if ((i > l) && (j == l)) {
        /* S(i, j) = S(i + 1, j) */
        twice(&p[j]);
      } else if ((i == w - 1) && (j < l)) {
        /* S(i, j) = S(i, j + 1) */
        p[j] = p[j + 1];
        twice(&p[j]);
      } else {
        /* S(i, j) = 1 + 1/2 * (S(i + 1, j) + S(i, j + 1)) */
        sum(&p[j], &q);
        sum(&p[j], &p[j + 1]);
      }
    }
    twice(&q);
  }

  half(&q);
  while (even(&p[0]) && (q.d[0] != 1)) {
    half(&p[0]);
    half(&q);
  }

  f = fopen("spoiler.out", "w");
  print(&p[0], f);
  print(&q, f);
  fclose(f);

  return 0;
}
